API Reference
*************************************

.. toctree::
   :caption: API Reference
   :hidden:
   
   cfg/index
   core/index
   io/index
   plotter/index
   scripts/index
   pyposcar/index


In this section, you can learn more about how PyProcar is intended parses DFT codes
and uses the electronic structure data

Highlights of the API include:
   - Python interface to DFT codes
   - Bands, Dos, and Fermi plotting

.. card:: cfg
   :link: cfg-index
   :link-type: ref
   :class-title: pyporcar-card-title

   Learn more about PyProcar's plotting configurations


.. card:: core API
   :link: core-api-index
   :link-type: ref
   :class-title: pyporcar-card-title

   Learn more about PyProcar's data types.


.. card:: io  API
   :link: io-api-index
   :link-type: ref
   :class-title: pyporcar-card-title

   Learn more about PyProcar's IO interfaces to DFT codes.


.. card:: plotter  API
   :link: plotter-api-index
   :link-type: ref
   :class-title: pyporcar-card-title

   Learn more about PyProcar's plotters (Density of States, Band Structure)


.. card:: pyposcar  API
   :link: pyposcar-api-index
   :link-type: ref
   :class-title: pyporcar-card-title

   Learn more about PyProcar's pyposcar modulue


.. card:: scripts  API
   :link: scripts-api-index
   :link-type: ref
   :class-title: pyporcar-card-title

   Learn more about PyProcar's scripts (bandsplot, dosplot, bandsdosplot)

